pub trait AdaptInto<D, Swp, Dwp, T>: Sized{
// Required method
fn adapt_into_using<M>(self, method: M) -> D
where M: TransformMatrix<T>;
// Provided method
fn adapt_into(self) -> D { ... }
}👎Deprecated since 0.7.7:
replaced by palette::chromatic_adaptation::AdaptIntoUnclamped
Trait to convert color with one reference white point into another
Converts a color with the source white point (Swp) into the destination white point (Dwp). Uses the bradford method for conversion by default.
Required Methods
Sourcefn adapt_into_using<M>(self, method: M) -> Dwhere
M: TransformMatrix<T>,
👎Deprecated since 0.7.7: replaced by palette::chromatic_adaptation::AdaptIntoUnclamped
fn adapt_into_using<M>(self, method: M) -> Dwhere
M: TransformMatrix<T>,
replaced by palette::chromatic_adaptation::AdaptIntoUnclamped
Convert the source color to the destination color using the specified method.
Provided Methods
Sourcefn adapt_into(self) -> D
👎Deprecated since 0.7.7: replaced by palette::chromatic_adaptation::AdaptIntoUnclamped
fn adapt_into(self) -> D
replaced by palette::chromatic_adaptation::AdaptIntoUnclamped
Convert the source color to the destination color using the bradford method by default.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.