pub trait TransformMatrix<T>{
// Required method
fn get_cone_response(&self) -> ConeResponseMatrices<T>;
// Provided method
fn generate_transform_matrix(
&self,
source_wp: Xyz<Any, T>,
destination_wp: Xyz<Any, T>,
) -> [T; 9] { ... }
}๐Deprecated since 0.7.7:
use the options from palette::lms::matrix or a custom matrix
Generates a conversion matrix to convert the Xyz tristimulus values from
one illuminant to another (source_wp to destination_wp)
Required Methods
Sourcefn get_cone_response(&self) -> ConeResponseMatrices<T>
๐Deprecated since 0.7.7: use the options from palette::lms::matrix or a custom matrix
fn get_cone_response(&self) -> ConeResponseMatrices<T>
use the options from palette::lms::matrix or a custom matrix
Get the cone response functions for the chromatic adaptation method
Provided Methods
Sourcefn generate_transform_matrix(
&self,
source_wp: Xyz<Any, T>,
destination_wp: Xyz<Any, T>,
) -> [T; 9]
๐Deprecated since 0.7.7: use the options from palette::lms::matrix or a custom matrix
fn generate_transform_matrix( &self, source_wp: Xyz<Any, T>, destination_wp: Xyz<Any, T>, ) -> [T; 9]
use the options from palette::lms::matrix or a custom matrix
Generates a 3x3 transformation matrix to convert color from one reference white point to another with the given cone_response